write_boulder: Write a list of records to a Boulder-IO text file.

Description Usage Arguments

View source: R/main.R

Description

Write a list of records to a Boulder-IO text file.

Usage

1
write_boulder(records, file = "", single = FALSE)

Arguments

records

A list of records. Each record is also a list of tags (names) and values. All values are converted with as.character. Tags with a vector of values are written on separate lines with the same tag.

file

A filename or a connection object. Use "" for STDOUT.

single

If TRUE, the input records is only a single record, not a list of records.


jensenlab/boulderio documentation built on Jan. 1, 2021, 4:35 a.m.